==> pocode-0.0.1.tar.gz: pocode-0.0.1/README.md <==
<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>



-------------------------------------------------------------------------------

## 📚简介

pocode是查看第三方库下载数据的小工具。

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

已同步到阿里镜像

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ pocode -U
```

-------------------------------------------------------------------------------

## 📝功能

| 名称         | 说明     | 演示代码                                                                |
|------------|--------|---------------------------------------------------------------------|
| count_line | 统计代码行数 | [查看](https://github.com/CoderWanFeng/pocode/demo/1、统计Python代码行数.py) | 

#### 相关资料：

- [📘官网：https://www.python-office.com/](https://www.python-office.com/)
- https://github.com/CoderWanFeng/pocode

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和python-office代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/wftools/issues)

-------------------------------------------------------------------------------

## 📌联系作者

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>

==> pocode-0.0.2.tar.gz: pocode-0.0.2/README.md <==
<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>



-------------------------------------------------------------------------------

## 📚简介

pocode是查看Python编程常用工具的代码集合。

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

已同步到阿里镜像

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ pocode -U
```

-------------------------------------------------------------------------------

## 📝功能

| 名称         | 说明     | 演示代码                                                                |
|------------|--------|---------------------------------------------------------------------|
| count_line | 统计代码行数 | [查看](https://github.com/CoderWanFeng/pocode/blob/main/demo/1%E3%80%81%E7%BB%9F%E8%AE%A1Python%E4%BB%A3%E7%A0%81%E8%A1%8C%E6%95%B0.py) | 
| @deprecated() | 标记函数过期 | [查看](https://github.com/CoderWanFeng/pocode/blob/main/demo/1%E3%80%81%E7%BB%9F%E8%AE%A1Python%E4%BB%A3%E7%A0%81%E8%A1%8C%E6%95%B0.py) | 

#### 相关资料：

- [📘官网：https://www.python-office.com/](https://www.python-office.com/)
- https://github.com/CoderWanFeng/pocode

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和python-office代码本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/wftools/issues)

-------------------------------------------------------------------------------

## 📌联系作者

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>
